AutoTypeAssociation

Struct AutoTypeAssociation 

pub struct AutoTypeAssociation {
    pub window: Option<String>,
    pub sequence: Option<String>,
}
A window association associated with an AutoType setting

Fields

window: Option<String>

The title of the window to match with this entry. The string MUST support * as a wildcard character.

sequence: Option<String>

A custom Auto-Type sequence. If the value is left empty, the sequence from is used or, if that is empty as well, the group or global default.