Database

Struct Database 

pub struct Database {
    pub config: DatabaseConfig,
    pub root: SerializableNodePtr,
    pub deleted_objects: HashMap<Uuid, Option<NaiveDateTime>>,
    pub meta: Meta,
}
A decrypted KeePass database

Fields

config: DatabaseConfig

Configuration settings of the database such as encryption and compression algorithms

root: SerializableNodePtr

Root node of the KeePass database

deleted_objects: HashMap<Uuid, Option<NaiveDateTime>>

References to previously-deleted objects and their deletion times.

meta: Meta

Metadata of the KeePass database

Implementations

Source

impl Database

pub fn purge_unused_custom_icons(&mut self) -> usize

Remove custom icons that are not referenced by any group, entry, or history item.

Returns the number of removed icons.

pub fn new(config: DatabaseConfig) -> Database

Create a new, empty database

pub fn node_get_parents(&self, node: &NodePtr) -> Vec<Uuid>

pub fn set_recycle_bin_enabled(&mut self, enabled: bool)

pub fn recycle_bin_enabled(&self) -> bool

pub fn node_is_recycle_bin(&self, node: &NodePtr) -> bool

pub fn node_is_in_recycle_bin(&self, node: Uuid) -> bool

pub fn get_recycle_bin(&self) -> Option<NodePtr>

pub fn create_recycle_bin(&mut self) -> Result<NodePtr>

pub fn remove_node_by_uuid(&mut self, uuid: Uuid) -> Result<NodePtr>

pub fn search_node_by_uuid(&self, uuid: Uuid) -> Option<NodePtr>

pub fn create_new_entry(&self, parent: Uuid, index: usize) -> Result<NodePtr>

pub fn create_new_group(&self, parent: Uuid, index: usize) -> Result<NodePtr>

Source

impl Database

pub fn open( source: &mut dyn Read, key: DatabaseKey, ) -> Result<Database, DatabaseOpenError>

Parse a database from a std::io::Read

pub fn parse( data: &[u8], key: DatabaseKey, ) -> Result<Database, DatabaseOpenError>

pub fn get_xml( source: &mut dyn Read, key: DatabaseKey, ) -> Result<Vec<u8>, DatabaseOpenError>

Helper function to load a database into its internal XML chunks

pub fn get_version( source: &mut dyn Read, ) -> Result<DatabaseVersion, DatabaseIntegrityError>

Get the version of a database without decrypting it

Source

impl Database

pub fn merge(&mut self, other: &Database) -> Result<MergeLog, MergeError>

Merge this database with another version of this same database. This function will use the UUIDs to detect that entries and groups are the same.

Source

impl Database

pub fn save( &self, destination: &mut dyn Write, key: DatabaseKey, ) -> Result<(), DatabaseSaveError>

Save a database to a std::io::Write