IconId

Struct IconId 

pub struct IconId(pub usize);
IconId is a usize that represents an icon in the database The value is the index of the icon in the database’s icon list

Tuple Fields

0: usize

Implementations

Source

impl IconId

pub const KEY: IconId

pub const WORLD: IconId

pub const WARNING: IconId

pub const NETWORK_SERVER: IconId

pub const MARKED_DIRECTORY: IconId

pub const USER_COMMUNICATION: IconId

pub const PARTS: IconId

pub const NOTEPAD: IconId

pub const WORLD_SOCKET: IconId

pub const IDENTITY: IconId

pub const PAPER_READY: IconId

pub const DIGICAM: IconId

pub const IRCOMMUNICATION: IconId

pub const MULTI_KEYS: IconId

pub const PLUG: IconId

pub const PDA: IconId

pub const BOOK_MARK: IconId

pub const CD_ROM: IconId

pub const MONITOR: IconId

pub const EMAIL: IconId

pub const CONFIG: IconId

pub const CLIPBOARD_READY: IconId

pub const PAPER_NEW: IconId

pub const SCREENSHOT: IconId

pub const THUNDER: IconId

pub const RADIO: IconId

pub const FLOPPY_DISK: IconId

pub const FTP: IconId

pub const FILM: IconId

pub const SECURITY_TERMINAL: IconId

pub const TERMINAL: IconId

pub const PRINTER: IconId

pub const GRID: IconId

pub const CHECKER_BOARD: IconId

pub const WRENCH: IconId

pub const INTERNET: IconId

pub const ZIP_FOLDER: IconId

pub const PERCENT: IconId

pub const WINDOWS_PC: IconId

pub const CLOCK: IconId

pub const SEARCH: IconId

pub const LANDSCAPE: IconId

pub const MEMORY: IconId

pub const RECYCLE_BIN: IconId

pub const CLIPBOARD: IconId

pub const STOP: IconId

pub const INFORMATION: IconId

pub const FILING_CABINET: IconId

pub const FOLDER: IconId

pub const FOLDER_OPEN: IconId

pub const DESKTOP: IconId

pub const LOCK_OPEN: IconId

pub const LOCKED: IconId

pub const APPROVED: IconId

pub const MARKER: IconId

pub const PICTURE_DOC: IconId

pub const CONTACT: IconId

pub const EXCEL_SHEET: IconId

pub const SECURIT_ACCOUNT: IconId

pub const REPAIR: IconId

pub const HOME: IconId

pub const STAR: IconId

pub const LINUX: IconId

pub const ANDROID: IconId

pub const APPLE: IconId

pub const WIKIPEDIA: IconId

pub const DOLLAR: IconId

pub const CERTIFICATE: IconId

pub const MOBILE_PHONE: IconId