Node

Trait Node 

pub trait Node: Any + Debug {
Show 14 methods // Required methods fn duplicate(&self) -> NodePtr; fn get_uuid(&self) -> Uuid; fn set_uuid(&mut self, uuid: Uuid); fn get_title(&self) -> Option<&str>; fn set_title(&mut self, title: Option<&str>); fn get_notes(&self) -> Option<&str>; fn set_notes(&mut self, notes: Option<&str>); fn get_icon_id(&self) -> Option<IconId>; fn set_icon_id(&mut self, icon_id: Option<IconId>); fn get_custom_icon_uuid(&self) -> Option<Uuid>; fn get_times(&self) -> &Times; fn get_times_mut(&mut self) -> &mut Times; fn get_parent(&self) -> Option<Uuid>; fn set_parent(&mut self, parent: Option<Uuid>);
}

Required Methods

fn duplicate(&self) -> NodePtr

fn get_uuid(&self) -> Uuid

fn set_uuid(&mut self, uuid: Uuid)

fn get_title(&self) -> Option<&str>

fn set_title(&mut self, title: Option<&str>)

fn get_notes(&self) -> Option<&str>

fn set_notes(&mut self, notes: Option<&str>)

fn get_icon_id(&self) -> Option<IconId>

fn set_icon_id(&mut self, icon_id: Option<IconId>)

fn get_custom_icon_uuid(&self) -> Option<Uuid>

fn get_times(&self) -> &Times

Get a timestamp field by name

Returning the NaiveDateTime which does not include timezone or UTC offset because KeePass clients typically store timestamps relative to the local time on the machine writing the data without including accurate UTC offset or timezone information.

fn get_times_mut(&mut self) -> &mut Times

fn get_parent(&self) -> Option<Uuid>

fn set_parent(&mut self, parent: Option<Uuid>)

Implementations

Source

impl dyn Node

pub fn downcast_ref<T: 'static>(&self) -> Option<&T>

pub fn downcast_mut<T: 'static>(&mut self) -> Option<&mut T>

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors