KdfConfig

Enum KdfConfig 

pub enum KdfConfig {
    Aes {
        rounds: u64,
    },
    Argon2 {
        iterations: u64,
        memory: u64,
        parallelism: u32,
        version: Version,
    },
    Argon2id {
        iterations: u64,
        memory: u64,
        parallelism: u32,
        version: Version,
    },
}
Choices for Key Derivation Functions (KDFs)

Variants



Aes

Derive keys with repeated AES encryption

Fields

rounds: u64


Argon2

Derive keys with Argon2d

Fields

iterations: u64

The number of iterations to perform when deriving keys

memory: u64

The amount of memory (in bytes) to use when deriving keys

KDBX stores this value in bytes, while the underlying Argon2 implementation expects KiB and converts internally when deriving keys.

parallelism: u32

The degree of parallelism to use when deriving keys

version: Version

The version of the Argon2 algorithm to use when deriving keys



Argon2id

Derive keys with Argon2id

Fields

iterations: u64

The number of iterations to perform when deriving keys

memory: u64

The amount of memory (in bytes) to use when deriving keys

KDBX stores this value in bytes, while the underlying Argon2 implementation expects KiB and converts internally when deriving keys.

parallelism: u32

The degree of parallelism to use when deriving keys

version: Version

The version of the Argon2 algorithm to use when deriving keys