DatabaseKey

Struct DatabaseKey 

pub struct DatabaseKey { /* private fields */ }
A KeePass key, which might consist of a password and/or a keyfile

Implementations

Source

impl DatabaseKey

pub fn with_password(self, password: &str) -> Self

pub fn with_password_from_prompt( self, prompt_message: &str, ) -> Result<Self, Error>

pub fn with_hmac_sha1_secret_from_prompt( self, prompt_message: &str, ) -> Result<Self, Error>

pub fn with_keyfile(self, keyfile: &mut dyn Read) -> Result<Self, Error>

Creates a database key with a keyfile

Errors

Fails if the keyfile cannot be read

pub fn with_challenge_response_key( self, challenge_response_key: ChallengeResponseKey, ) -> Self

pub fn perform_challenge( self, kdf_seed: &[u8], ) -> Result<Self, DatabaseKeyError>

pub fn new() -> Self

pub fn is_empty(&self) -> bool

Returns true if the database key is not associated with any key component.